@@ -11,8 +11,8 @@
 #include "kgamerendererclient.h"
 #include <libkdegames_export.h>
 // Qt
-#include <QObject>
 #include <QGraphicsItem>
+#include <QObject>
 // Std
 #include <memory>
 
@@ -29,16 +29,18 @@ class KGameRenderedItemPrivate;
  */
 class KDEGAMES_EXPORT KGameRenderedItem : public QGraphicsPixmapItem, public KGameRendererClient
 {
-	public:
-		///Creates a new KGameRenderedItem which renders the sprite with the
-		///given @a spriteKey as provided by the given @a renderer.
-		KGameRenderedItem(KGameRenderer* renderer, const QString& spriteKey, QGraphicsItem* parent = nullptr);
-		virtual ~KGameRenderedItem();
-	protected:
-		void receivePixmap(const QPixmap& pixmap) override;
-	private:
-		friend class KGameRenderedItemPrivate;
-		std::unique_ptr<KGameRenderedItemPrivate> const d;
+public:
+    /// Creates a new KGameRenderedItem which renders the sprite with the
+    /// given @a spriteKey as provided by the given @a renderer.
+    KGameRenderedItem(KGameRenderer *renderer, const QString &spriteKey, QGraphicsItem *parent = nullptr);
+    ~KGameRenderedItem() override;
+
+protected:
+    void receivePixmap(const QPixmap &pixmap) override;
+
+private:
+    friend class KGameRenderedItemPrivate;
+    std::unique_ptr<KGameRenderedItemPrivate> const d;
 };
 
 #endif // KGAMERENDEREDITEM_H
